function [x_dot,residualLoads,markerPositions,forceValues] = getOpenSimValues(time,states,controls,options)
%GETOPENSIMVALUES This function communicates with Opensim models and
%methods via mex files
%   INPUTS
% time: m x 1 vector of times (time vector for set of collocation points).

% states: m x n matrix of states. They must correspond to those of opensim
% model in terms of number of states and order.

% controls: m x p matrix of controls. They must correspond to those of opensim
% model in terms of number of controls and order.

% options: 1 x 4 vector of ones and zeros. A one corresponds to a desired
% output. The order is the following:
% 1st place: state derivative x_dot is desired (e.g. [1 0 0 0]). As of now, always
% must be true.
% 2nd place: Residual loads are desired (e.g. [1 1 0 0]). 
% 3rd place: Marker positions are required (e.g. [1 0 1 0])
% 4th place: Force values are required (e.g. [1 0 0 1])
% If all are desired then [1 1 1 1]

%   OUTPUTS
% x_dot: m x n matrix of state derivatives

% residualLoads: m x n matrix of residual loads (from inverse dynamics
% solver with muscles included, unless disabled)

% markerPositions: m x numMarkers x 3 matrix of each marker position
% expressed in the ground coordinate system. First dimension is number of
% frames of collocation points, 2nd dimension corresponds to each marker,
% 3rd dimension allocates each of the 3 position coordinates

% forceValues: m x q matrix of forces being reported by the force methods

% --------Start main function here--------
if options(1) == 0
    error('Must calculate x_dot. Set option 1 to 1')
end

if options==[1 0 0 0]
x_dot = opensimDeriv(time,states,controls,options);
residualLoads = NaN;
markerPositions = NaN;
forceValues = NaN;
end

if options==[1 1 0 0]
[x_dot, residualLoads] = opensimDeriv(time,states,controls,options);
markerPositions = NaN;
forceValues = NaN;
end

if options==[1 0 1 0]
[x_dot,residualLoads,markerPositions] = opensimDeriv(time,states,controls,options);
residualLoads = NaN;
forceValues = NaN;
end

if options==[1 0 0 1]
[x_dot,residualLoads,markerPositions,forceValues] = opensimDeriv(time,states,controls,options);
residualLoads = NaN;
markerPositions = NaN;
end

if options==[1 1 1 0]
[x_dot,residualLoads,markerPositions] = opensimDeriv(time,states,controls,options);
forceValues = NaN;
end

if options==[1 0 1 1]
[x_dot,residualLoads,markerPositions,forceValues] = opensimDeriv(time,states,controls,options);
residualLoads = NaN;
end

if options==[1 1 1 1]
[x_dot,residualLoads,markerPositions,forceValues] = opensimDeriv(time,states,controls,options);
end


end
